# SMB3 enemy compatibility

Compiled by Spinzig.

Clan 1 are enemies that work with the all the clans but not other groups within clan 1 (eg. Dry Bones doesn't work with Koopas).

Clan 2 are compatible with every Clan 1 enemy but not other groups of Clan 2 (eg. you can have either Spike and Dry Bones or Spike and a Koopa, but you can't have Spike and a Lakitu).

Clan 3 are bosses that use tiles from both clans. They're not compatible with anything as far as I know. I still don't know if there are enemies that work with them.

## Clan 1 enemies

Group 1 | Group 2 | Group 3 | Group 4 | Group 5
Dry Bones | Left Rocket Engine | Koopa Troopa | Lava Lotus | Boom-Boom
P-Switch door (fortress) | Upward Rocket Engine | Goomba |  | Flying Boom
| Right Rocket Engine | Paratroopa |  |
| Downward Rocket Engine | Para Goomba |  |
|  | Pile Driver Micro Goomba |  |
|  | Bullet Bill |  |
|  | Missile Bill |  |
|  | Venus Fire traps |  |
|  | Piranha Plants |  |
|  | Cheep Cheeps |  |
|  | Rotary Lift |  |

## Clan 2 enemies

Clan 1 (Bros.) | Clan 2 (Sky) | Clan 3 (Dungeon) | Clan 4 (Underground, Hills) | Clan 5 (Ship) | Clan 6 (Koopa Kid) | Clan 7 (Spike) | Clan 8 (Water)
Boomerang Bros. | Falling platform | Podoboo | Buzzy | Cannonballs | Koopa Kids | Spike | Blooper
Hammer Bros. | Sideways platform | Rotodisc | Spiny | Bobomb 2 | Sun? | Chain Chomp | Mother Bloopers
Fire Bros. | Wire platform | Double Roto | Lakitu | Rocky Wrench |  | Chain Chomp head | Big Bertha
Sledge Bros. | Firesnake | Thwomps | Bobomb | BG Clouds |  | Buster Beetle | Boss Bass
| Fire Chomp | Boo Diddley | Kuribo's Goomba | Propeller |  | Ptooie | Water lift
| Parabeetles | Stretch |  |  |  | Moving Ptooie | Spiky Cheep Cheep
|  | Blue lift |  |  |  | Nipper | Baby Cheep Cheep
|  |  |  |  |  | Walking Nipper |
|  |  |  |  |  | Fire Nipper |

## Loose ends

There are a few things I'm not sure of.

1. Firstly, Boom-Boom works with flying Boom-Boom, but if you kill Boom-Boom, the crystal ball with make Boom-Boom glitch until you hit him and he stops flying. He looks like a glitchy Dry Bones, so I think the crystal ball may be in another class.
2. The Sun may be in the Koopa Kid class. I think he works with them.
3. Ptooies and Moving Ptooies are half-compatible with some groups. Pipe Ptooies are just Piranha plants, so they actually work with other clan 2 enemies (but their spiked ball glitches). Moving ones have the head of a Piranha plant and a different body, so they don't work with other clan 2 enemy groups as well.
4. In Mario Allstars, the groups are completely different, and I think level specific, like Mario World.
5. I found a good way to have multiple groups in levels is space them out and put blocks or something so they cannot meet and glitch each other. Shelled enemies like Buzzies are good in water as then they can't be stomped in there, and the shell cannot be carried over to an enemy that may glitch. I guess people may not mind a few small glitches, so this isn't a major thing, but it helps levels maintain a more professional look.
6. There are still unused sprites that look glitched no matter what. I don't know what these are.

That's all for now. Hope that helps!